@@ -2,22 +2,15 @@
 #' @description Described in Chapter 5 "The Ordered rx2 Table"
 #' @param n the observed counts (an rx2 matrix)
 #' @param a scores assigned to the rows
-#' @param printresults display results
 #' @examples
-#'
-#' # Alcohol consumption and malformations (Mills and Graubard, 1987)
-#' n <- rbind(c(48, 17066), c(38, 14464), c(5, 788), c(1, 126), c(1, 37))
-#' a <- c(1, 2, 3, 4, 5)
-#' CochranArmitage_MH_tests_rx2(n, a)
-#'
-#' # Elevated troponin T levels in stroke patients (Indredavik et al., 2008)
-#' n <- rbind(c(8, 53), c(10, 48), c(11, 100), c(22, 102), c(6, 129))
-#' a <- c(1, 2, 3, 4, 5)
-#' CochranArmitage_MH_tests_rx2(n, a)
-#'
+#' CochranArmitage_MH_tests_rx2(mills_graubard_1987, c(1, 2, 3, 4, 5))
+#' CochranArmitage_MH_tests_rx2(indredavik_2008, c(1, 2, 3, 4, 5))
 #' @export
-#' @return A list containing observed statistics and p-values
-CochranArmitage_MH_tests_rx2 <- function(n, a, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+CochranArmitage_MH_tests_rx2 <- function(n, a) {
+  validateArguments(mget(ls()))
   r <- nrow(n)
   nip <- apply(n, 1, sum)
   N <- sum(n)
@@ -61,11 +54,16 @@ CochranArmitage_MH_tests_rx2 <- function(n, a, printresults = TRUE) {
   results$Z_MH <- Z_MH
   results$P_MH <- P_MH
 
-  if (printresults) {
-    print(sprintf("Cochran-Armitage test:          T = %6.3f, P = %7.5f", Z_CA, P_CA))
-    print(sprintf("Modified Cochran-Armitage test: T = %6.3f, P = %7.5f", Z_CA_mod, P_CA_mod))
-    print(sprintf("Mantel-Haenszel test:           T = %6.3f, P = %7.5f", Z_MH, P_MH))
+  printresults <- function() {
+    my_sprintf_cat(
+      "Cochran-Armitage test:          T = %6.3f, P = %7.5f\n", Z_CA, P_CA
+    )
+    my_sprintf_cat(
+      "Modified Cochran-Armitage test: T = %6.3f, P = %7.5f\n", Z_CA_mod, P_CA_mod
+    )
+    my_sprintf_cat(
+      "Mantel-Haenszel test:           T = %6.3f, P = %7.5f", Z_MH, P_MH
+    )
   }
-
-  invisible(results)
+  return(contingencytables_result(results, printresults))
 }
