@@ -3,19 +3,16 @@
 #' @description Described in Chapter 8 "The Paired 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (F = no, T= yes)
 #' @examples
-#' n <- rbind(c(1, 1), c(7, 12))
-#' MOVER_Wilson_score_CI_paired_2x2(n)
-#'
-#' # Complete response before and after consolidation therapy
-#' # (Cavo et al., 2012)
-#' n <- matrix(c(59, 6, 16, 80), 2, byrow = TRUE)
-#' MOVER_Wilson_score_CI_paired_2x2(n)
+#' MOVER_Wilson_score_CI_paired_2x2(bentur_2009)
+#' MOVER_Wilson_score_CI_paired_2x2(cavo_2012)
 #'
 #' @export
-#' @return A list containing lower, upper and point estimates of the statistic
-MOVER_Wilson_score_CI_paired_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+MOVER_Wilson_score_CI_paired_2x2 <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
   N <- sum(n)
   pi1phat <- (n[1, 1] + n[1, 2]) / N
   pip1hat <- (n[1, 1] + n[2, 1]) / N
@@ -24,10 +21,10 @@ MOVER_Wilson_score_CI_paired_2x2 <- function(n, alpha = 0.05, printresults = TRU
   estimate <- (n[1, 1] + n[1, 2]) / (n[1, 1] + n[2, 1])
 
   # Use Wilson score intervals for pi_1+ and pi_ + 1
-  tmp <- Wilson_score_CI_1x2(n[1, 1] + n[1, 2], N, alpha, printresults = FALSE)
+  tmp <- Wilson_score_CI_1x2(n[1, 1] + n[1, 2], N, alpha)
   l1 <- tmp[[1]]
   u1 <- tmp[[2]]
-  tmp <- Wilson_score_CI_1x2(n[1, 1] + n[2, 1], N, alpha, printresults = FALSE)
+  tmp <- Wilson_score_CI_1x2(n[1, 1] + n[2, 1], N, alpha)
   l2 <- tmp[[1]]
   u2 <- tmp[[2]]
 
@@ -46,12 +43,10 @@ MOVER_Wilson_score_CI_paired_2x2 <- function(n, alpha = 0.05, printresults = TRU
     U <- Inf
   }
 
-  if (printresults) {
-    .print("The MOVER Wilson score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)\n", estimate, 100 * (1 - alpha), L, U)
-  }
-  invisible(list(L = L, U = U, estimate = estimate))
-}
-
-.print <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
+  return(
+    contingencytables_result(
+      list(L = L, U = U, estimate = estimate),
+      sprintf("The MOVER Wilson score CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)\n", estimate, 100 * (1 - alpha), L, U)
+    )
+  )
 }
