@@ -3,33 +3,26 @@
 #' @description Described in Chapter 10 "Stratified 2x2 Tables and Meta-Analysis"
 #' @param n the observed table (a 2x2xk matrix, where k is the number of strata)
 #' @param link the link function ('linear', 'log', or 'logit')
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
 #' # Smoking and lung cancer (Doll and Hill, 1950)
-#' n <- array(dim = c(2, 2, 2))
-#' n[, , 1] <- matrix(c(647, 622, 2, 27), 2, byrow = TRUE)
-#' n[, , 2] <- matrix(c(41, 28, 19, 32), 2, byrow = TRUE)
-#' Pearson_LR_homogeneity_test_stratified_2x2(n)
+#' Pearson_LR_homogeneity_test_stratified_2x2(doll_hill_1950)
 #'
 #' # Prophylactice use of Lidocaine in myocardial infarction (Hine et al., 1989)
-#' n <- array(0, dim = c(2, 2, 6))
-#' n[, , 1] <- rbind(c(2, 37), c(1, 42))
-#' n[, , 2] <- rbind(c(4, 40), c(4, 40))
-#' n[, , 3] <- rbind(c(6, 101), c(4, 106))
-#' n[, , 4] <- rbind(c(7, 96), c(5, 95))
-#' n[, , 5] <- rbind(c(7, 103), c(3, 103))
-#' n[, , 6] <- rbind(c(11, 143), c(4, 142))
-#' Pearson_LR_homogeneity_test_stratified_2x2(n)
+#' Pearson_LR_homogeneity_test_stratified_2x2(hine_1989)
 #'
 #' @export
-#' @return A list containing the two-sided p-value, the test statistic and the degrees of freedom for the likelihood ratio and the Pearson chi-squared tests
-Pearson_LR_homogeneity_test_stratified_2x2 <- function(n, link = "logit", printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Pearson_LR_homogeneity_test_stratified_2x2 <- function(n, link = "logit") {
+  validateArguments(mget(ls()))
+
   n1pk <- apply(n[1, , ], 2, sum)
   n2pk <- apply(n[2, , ], 2, sum)
   K <- dim(n)[3]
 
   # Get the estimated probabilities
-  results <- ML_estimates_and_CIs_stratified_2x2(n, link, 0.05, FALSE)
+  results <- ML_estimates_and_CIs_stratified_2x2(n, link, 0.05)
   pihat <- results$pihat
 
   if (any(pihat < 0)) {
@@ -96,15 +89,10 @@ Pearson_LR_homogeneity_test_stratified_2x2 <- function(n, link = "logit", printr
   results$T_Pearson <- T_Pearson
   results$df_Pearson <- df
 
-  if (printresults) {
-    .print("The likelihood ratio test: P = %7.5f, T0 = %5.3f (df = %i)\n", P_LR, T_LR, df)
-    .print("The Pearson chi-squared test: P = %7.5f, T0 = %5.3f (df = %i)\n", P_Pearson, T_Pearson, df)
+  printresults <- function() {
+    my_sprintf_cat("The likelihood ratio test: P = %7.5f, T0 = %5.3f (df = %i)\n", P_LR, T_LR, df)
+    my_sprintf_cat("The Pearson chi-squared test: P = %7.5f, T0 = %5.3f (df = %i)\n", P_Pearson, T_Pearson, df)
   }
 
-  invisible(results)
-}
-
-
-.print <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
+  return(contingencytables_result(results, printresults))
 }
