@@ -2,27 +2,26 @@
 #' @description The Pearson chi-squared test for association in 2x2 tables
 #' @description Described in Chapter 4 "The 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
 #' # Example: A lady tasting a cup of tea
-#' n <- rbind(c(3, 1), c(1, 3))
-#' Pearson_chi_squared_test_2x2(n)
+#' Pearson_chi_squared_test_2x2(tea)
 #'
 #' # Example: Perondi et al. (2004)
-#' n <- rbind(c(7, 27), c(1, 33))
-#' Pearson_chi_squared_test_2x2(n)
+#' Pearson_chi_squared_test_2x2(perondi_2004)
 #'
 #' # Example: Lampasona et al. (2013)
-#' n <- rbind(c(9, 4), c(4, 10))
-#' Pearson_chi_squared_test_2x2(n)
+#' Pearson_chi_squared_test_2x2(lampasona_2013)
 #'
 #' # Example: Ritland et al. (2007)
-#' n <- rbind(c(0, 16), c(15, 57))
-#' Pearson_chi_squared_test_2x2(n)
+#' Pearson_chi_squared_test_2x2(ritland_2007)
 #'
 #' @export
-#' @return A data frame containing the two-sided p-value, the statistic and the degrees of freedom
-Pearson_chi_squared_test_2x2 <- function(n, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Pearson_chi_squared_test_2x2 <- function(n) {
+  validateArguments(mget(ls()))
+
   n1p <- n[1, 1] + n[1, 2]
   n2p <- n[2, 1] + n[2, 2]
   np1 <- n[1, 1] + n[2, 1]
@@ -41,10 +40,11 @@ Pearson_chi_squared_test_2x2 <- function(n, printresults = TRUE) {
     P <- 1.0
   }
 
-  if (printresults) {
-    print(sprintf("The Pearson chi-squared test: P = %7.5f, T = %5.3f (df = %i)", P, T0, df), quote = FALSE)
-  }
+  return(
+    contingencytables_result(
+      list(p.value = P, statistic = T0, df = df),
+      sprintf("The Pearson chi-squared test: P = %7.5f, T = %5.3f (df = %i)", P, T0, df)
+    )
+  )
 
-  res <- data.frame(p.value = P, statistic = T0, df = df)
-  invisible(res)
 }
