@@ -3,32 +3,17 @@
 #' @description Described in Chapter 7 "The rxc Table"
 #' @param n the observed table (an rxc matrix)
 #' @param alpha the nominal significance level, used to compute a 100(1-alpha)# confidence interval
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
-#' # Colorectal cancer (Table 7.7)
-#' n <- rbind(
-#'   c(2, 4, 29, 19), c(7, 6, 116, 51), c(19, 27, 201, 76), c(18, 22, 133, 54)
-#' )
-#' Spearman_correlation_coefficient_rxc(n)
-#' \dontrun{
-#' # Breast Tumor (Table 7.8)
-#' n <- matrix(
-#'   c(15, 35, 6, 9, 6, 2, 4, 2, 11, 11, 0, 0, 1, 10, 21),
-#'   ncol = 5, byrow = TRUE
-#' )
-#' Spearman_correlation_coefficient_rxc(n)
-#'
-#' # Self-rated health (Table 7.9)
-#' n <- matrix(
-#'   c(2, 3, 3, 3, 2, 58, 98, 14, 8, 162, 949, 252, 4, 48, 373, 369),
-#'   ncol = 4, byrow = TRUE
-#' )
-#' Spearman_correlation_coefficient_rxc(n)
-#' }
-#'
+#' Spearman_correlation_coefficient_rxc(table_7.7)
+#' Spearman_correlation_coefficient_rxc(table_7.8)
+#' Spearman_correlation_coefficient_rxc(table_7.9)
 #' @export
-#' @return A list containing the Spearman correlation coefficient, and the Fieller and Bonett-Wright confidence intervals
-Spearman_correlation_coefficient_rxc <- function(n, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Spearman_correlation_coefficient_rxc <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
+
   r <- nrow(n)
   c <- ncol(n)
   nip <- apply(n, 1, sum)
@@ -93,14 +78,14 @@ Spearman_correlation_coefficient_rxc <- function(n, alpha = 0.05, printresults =
   L_BW <- (exp(2 * l_BW) - 1) / (exp(2 * l_BW) + 1)
   U_BW <- (exp(2 * u_BW) - 1) / (exp(2 * u_BW) + 1)
 
-  if (printresults) {
-    .print("Spearman correlation w / Fieller CI:       rho = %7.4f (%g%% CI %7.4f to %7.4f)\n", rho, 100 * (1 - alpha), L, U)
-    .print("Spearman correlation w / Bonett-Wright CI: rho = %7.4f (%g%% CI %7.4f to %7.4f)\n", rho, 100 * (1 - alpha), L_BW, U_BW)
+  printresults <- function() {
+    my_sprintf_cat("Spearman correlation w / Fieller CI:       rho = %7.4f (%g%% CI %7.4f to %7.4f)\n", rho, 100 * (1 - alpha), L, U)
+    my_sprintf_cat("Spearman correlation w / Bonett-Wright CI: rho = %7.4f (%g%% CI %7.4f to %7.4f)", rho, 100 * (1 - alpha), L_BW, U_BW)
   }
 
-  invisible(list(rho = rho, L = L, U = U, L_BW = L_BW, U_BW = U_BW))
-}
-
-.print <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
+  return(
+    contingencytables_result(
+      list(rho = rho, L = L, U = U, L_BW = L_BW, U_BW = U_BW), printresults
+    )
+  )
 }
